package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````O!L``#0```#(D@````0`!30`(``)
M`"@`'0`<``$``'"0B```D(@``)"(``#H````Z`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!\B0``?(D```4```````$`
M`0```-B.``#8C@$`V(X!`*0"``"X$@``!@```````0`"````X(X``.".`0#@
MC@$`(`$``"`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DV(X`
M`-B.`0#8C@$`*`$``"@!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`EA'-;;_6P+NE@B>O);&I_^)L&]@$
M````$`````$```!'3E4```````,````"`````````&$```!M````````````
M``!:````1```````````````!P``````````````.````#L`````````2P``
M`#H```!F`````````"L```!1````4@```#,```!A````:0````,````P````
M```````````B````/@```#\``````````````!,```!*````-P```$X`````
M````;````"``````````"0`````````:`````````$(```!B````4````#0`
M````````30```&0`````````#@```#P``````````````%L````R````20``
M`$<`````````````````````````0``````````````````````````7````
M*@```"T```!!````(0```"8```````````````L```!(````.0```#T```!5
M````-@```"\```!K````0P```````````````````&4```!6`````````$4`
M``!8````)P````8````C````3```````````````````````````````````
M````````````!```````````````8P``````````````````````````````
M`````!$```!3````5P``````````````````````````````````````````
M`````````!P`````````9P```&H`````````'@``````````````&P``````
M``!H`````````!`````````````````````/````'P```"4````(````#0``
M`!T````L``````````````!9````&0```$\``````````````%0````D````
M70```"X````5````*0```!@````,``````````````!<````,0```!0```!&
M````7@````````````````````````````````````4`````````````````
M```U````````````````````$@```````````````````"@````6````````
M`````````````````````````````````%\`````````"@````````!@````
M```````````1````3@````@````(`````9`0!"5`!(`H@``%H(90A(`!```+
M*`2,.*`218H```A.````3P```%(```!6````5P```%\```!@````80```&,`
M``!D````9@```&<```!H````:0```&P```````````````&O-.ANQ=\?SMY'
M+6M_FGPNQ9NVU&34?'94/)0A_^0.V7%8'.)'Q@&R`8MOK$OCP$+ZUX?"Y3\L
M6.^7>;KCDGS[H6Q@:PE#UF>OS&9"1=7LB0=PTPT4XIXR8MOMV\WCGA6,)<P-
M.I<+?ZF<F^"G`@IJ&IY0O]I7&Z/@^TD``````````````````````````!P6
M`````````P`,```````\D0$```````,`&`#Z`0`````````````2````W```
M````````````$@````@"`````````````!(```!S`@`````````````2````
M@P``````````````$@```-$``````````````!$```!5`0`````````````2
M````X`(`````````````$@```"`#`````````````!(```#R````````````
M```2`````0``````````````(````)P"`````````````!(````C`0``````
M```````2````$P$`````````````$@```#$"`````````````!(````%`0``
M```````````2````6@(`````````````$@```!```````````````"````!S
M`0`````````````2````C`(`````````````$@```.$``````````````!(`
M``"4`0`````````````2````L@$`````````````$@```-("````````````
M`!(````L```````````````@````1@``````````````$@```$4!````````
M`````!(```!C```````````````2````P```````````````$@```'0`````
M`````````!(````J`@`````````````2````\P$`````````````$@```%,"
M`````````````!(````E!``````````````2````I```````````````$@``
M`/0"`````````````!$```"-`0`````````````2````#@,`````````````
M$0```#@"`````````````!(```#&`0`````````````2````-P$`````````
M````$@```-D!`````````````!(```![`@`````````````2````'`(`````
M````````$@```.8``````````````!(```"J`0`````````````2````;`$`
M````````````$@```.(!`````````````!(```!%`@`````````````2````
M(P(`````````````$@```#\"`````````````!(```#*`@`````````````2
M````_`(`````````````$@```/,"`````````````"$```"/````````````
M```2````%0(`````````````$@```&`!`````````````!(```"3`@``````
M```````2````\@(`````````````$0```(4"`````````````!$```!H`@``
M```````````2````LP``````````````$0```*,"`````````````!(```!^
M`0`````````````1````O`(`````````````$@```-$!`````````````!(`
M```L`0`````````````2``````(`````````````$@```%0`````````````
M`!(````W`P`````````````2````#@(`````````````$@```-D"````````
M`````!(```#,`0`````````````2````F0$`````````````$@```*T"````
M`````````"(```"0!```D*$!```````0`!D`+@0```@Y``"@````$@`.`+4$
M``"L+@``J`<``!(`#@#M`@``#!D``+`"```2``X`E0,``&PF```$````$@`.
M`,,#``!4-@``M`(``!(`#@!6!```?)$!```````0`!D`VP0``'`F``"8`@``
M$@`.`)L$``!\D0$``````!``&0"F`P``""D``"@````2``X`V0,``,PL``"L
M````$@`.`#H$``!T20``!````!$`$`!D!```%$8``#@!```2``X`;P0``*`D
M``!<````$@`.`'<$``"0H0$``````!``&0"P!```D*$!```````0`!D`R00`
M`)PM```0`0``$@`.`$D$```\D0$``````!``&`#]`P``,"D``%`!```2``X`
MP@0``'R1`0``````$``8`.@$``!XD0$`!````!$`&`"S`P``5$D```0````2
M``X`3P0``+P;````````$@`.`'\$``#,2```B````!(`#@"G!```M$4``&``
M```2``X`2P0``#R1`0``````(``8`!,$``!X+0``)````!(`#@#G`P``>"4`
M`/0````2``X`"00``$Q'``"``0``$@`.`(\$``"0H0$``````!``&0#R!```
M@"H``$P"```2``X``%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-
M0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES
M7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O
M;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L
M7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T
M:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R
M;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L7W!A
M<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W
M<F%P`&]P96XV-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P=&AR
M96%D7V=E='-P96-I9FEC`&-L;W-E`&5X:70`<W1R;F-M<`!C;&]S961I<@!?
M7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE
M;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T
M<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?
M;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D
M;&EN:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT
M9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN
M`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R
M9`!?7V%E86)I7W5N=VEN9%]C<'!?<'(P`%]?865A8FE?=6YW:6YD7V-P<%]P
M<C$`;&EB<&5R;"YS;P!L:6)P=&AR96%D+G-O+C``;&EB8RYS;RXV`&QD+6QI
M;G5X+6%R;6AF+G-O+C,`;&EB9V-C7W,N<V\N,0!P87)?8W5R<F5N=%]E>&5C
M`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U7V9I;FD`6%-?26YT97)N86QS7U!!
M4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A
M<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I
M9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`7U]B
M<W-?<W1A<G1?7P!S:&%?=7!D871E`'AS7VEN:70`7U]E;F1?7P!?7VQI8F-?
M8W-U7VEN:70`7U]B<W-?96YD7U\`7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N
M9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F
M:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN:71?96YV`$=,24)#7S(N-`!'0T-?
M,RXU`"]U<W(O;&EB+W!E<FPU+S4N,C8N,2]A<FUV-VPM;&EN=7@M=&AR96%D
M+6UU;'1I+T-/4D4``````````@````(``@`````````"``,```````(`````
M``(````"```````"``(`!``$``(``````````````````@`"``(``@````(`
M!``%``(`!`````(``@`"````!``"``(``@`"``(``@`"``(````"`````@`"
M``(``@````(````"``(````"`````P`"``(``@`$``(``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$`<P,``!`````@````%&EI#0``!0#_!`````````$``0!9`P``
M$````"`````4:6D-```$`/\$`````````0`!`(<#```0````(````%4F>0L`
M``,`"04````````!``$`:0,``!``````````%&EI#0```@#_!````````-B.
M`0`7````W(X!`!<```#\D`$`%P```!R1`0`7````.)$!`!<```!`D0$`%P``
M`$B1`0`7````3)$!`!<```!4D0$`%P```%B1`0`7````7)$!`!<```!@D0$`
M%P```&21`0`7````;)$!`!<```!PD0$`%P```'B1`0`7`````)$!`!4(```$
MD0$`%0P```B1`0`5#0``#)$!`!44```0D0$`%1L``!21`0`5'0``&)$!`!4>
M```@D0$`%28``"21`0`5*```*)$!`!4^```LD0$`%4```#"1`0`50@``-)$!
M`!5-```,D`$`%@,``!"0`0`6!```%)`!`!8%```8D`$`%@8``!R0`0`6!P``
M()`!`!8)```DD`$`%@H``"B0`0`6#0``+)`!`!8.```PD`$`%@\``#20`0`6
M$```.)`!`!81```\D`$`%A(``$"0`0`6$P``1)`!`!85``!(D`$`%A8``$R0
M`0`6%P``4)`!`!88``!4D`$`%AD``%B0`0`6&@``7)`!`!8<``!@D`$`%A\`
M`&20`0`6(```:)`!`!8A``!LD`$`%B(``'"0`0`6(P``=)`!`!8D``!XD`$`
M%B4``'R0`0`6)P``@)`!`!8I``"$D`$`%BH``(B0`0`6*P``C)`!`!8L``"0
MD`$`%BT``)20`0`6+@``F)`!`!8O``"<D`$`%C```*"0`0`6,0``I)`!`!8R
M``"HD`$`%C,``*R0`0`6-```L)`!`!8U``"TD`$`%C8``+B0`0`6-P``O)`!
M`!8Y``#`D`$`%CH``,20`0`6.P``R)`!`!8\``#,D`$`%C\``-"0`0`600``
MU)`!`!9#``#8D`$`%D0``-R0`0`610``X)`!`!9&``#DD`$`%D<``.B0`0`6
M20``[)`!`!9*``#PD`$`%DL``/20`0`63```^)`!`!9-```(0"WI>P$`ZPB`
MO>@$X"WE!."?Y0[@C^`(\+[ER'D!``#&C^(7RHSBR/F\Y0#&C^(7RHSBP/F\
MY0#&C^(7RHSBN/F\Y0#&C^(7RHSBL/F\Y0#&C^(7RHSBJ/F\Y0#&C^(7RHSB
MH/F\Y0#&C^(7RHSBF/F\Y0#&C^(7RHSBD/F\Y0#&C^(7RHSBB/F\Y0#&C^(7
MRHSB@/F\Y0#&C^(7RHSB>/F\Y0#&C^(7RHSB</F\Y0#&C^(7RHSB:/F\Y0#&
MC^(7RHSB8/F\Y0#&C^(7RHSB6/F\Y0#&C^(7RHSB4/F\Y0#&C^(7RHSB2/F\
MY0#&C^(7RHSB0/F\Y0#&C^(7RHSB./F\Y0#&C^(7RHSB,/F\Y0#&C^(7RHSB
M*/F\Y0#&C^(7RHSB(/F\Y0#&C^(7RHSB&/F\Y0#&C^(7RHSB$/F\Y0#&C^(7
MRHSB"/F\Y0#&C^(7RHSB`/F\Y0#&C^(7RHSB^/B\Y0#&C^(7RHSB\/B\Y0#&
MC^(7RHSBZ/B\Y0#&C^(7RHSBX/B\Y0#&C^(7RHSBV/B\Y0#&C^(7RHSBT/B\
MY0#&C^(7RHSBR/B\Y0#&C^(7RHSBP/B\Y0#&C^(7RHSBN/B\Y0#&C^(7RHSB
ML/B\Y0#&C^(7RHSBJ/B\Y0#&C^(7RHSBH/B\Y0#&C^(7RHSBF/B\Y0#&C^(7
MRHSBD/B\Y0#&C^(7RHSBB/B\Y0#&C^(7RHSB@/B\Y0#&C^(7RHSB>/B\Y0#&
MC^(7RHSB</B\Y0#&C^(7RHSB:/B\Y0#&C^(7RHSB8/B\Y0#&C^(7RHSB6/B\
MY0#&C^(7RHSB4/B\Y0#&C^(7RHSB2/B\Y0#&C^(7RHSB0/B\Y0#&C^(7RHSB
M./B\Y0#&C^(7RHSB,/B\Y0#&C^(7RHSB*/B\Y0#&C^(7RHSB(/B\Y0#&C^(7
MRHSB&/B\Y0#&C^(7RHSB$/B\Y0#&C^(7RHSB"/B\Y0#&C^(7RHSB`/B\Y0#&
MC^(7RHSB^/>\Y0#&C^(7RHSB\/>\Y?1!;>%80I_E6#*?Y?A@S>$0X(WE)-!-
MX@1`C^`,((WE#""-XA`0C>40$(WB%`"-Y0-0E.<4`(WB`#"5Y1PPC>7<___K
M("*?Y2`RG^4"()3G`P"4YP(0H.'["P#K$#*?Y0,PE.<`<-/E``!7XU8```H`
M,I_E`V"4YP``EN5A___K[C/0Y0`@H.$``);E`C"#X^XSPN5;___K%&"=Y>XS
MT.4$((;B`V"&X@$P@^,'`7+C[C/`Y5H``(H"`:#AI?__Z[0AG^6T$9_E$#"=
MY13@G>4"((_@`1"/X`!`D>4$`(+EG!&?Y0$`7N.8(9_E$."@TP#`D^4!$(_@
M`B"/X`#`@.42`(#I#""`Y0@``-H.(8/@#!"`X@0P@^($P)/D`@!3X03`H>7[
M__\:`^".X@[AH.$`$*#C4$&?Y08@H.$`,*#A`!"-Y0X0@.=`$9_E!$"/X`P`
ME.4!$(_@`___ZP!@4.(K```**$&?Y1APC>($0(_@#`"4Y4K__^L8`9_E!Q"@
MX0``C^"M``#K``!0XQL```H$,9_E`S"/X`P`D^7F_O_K'O__ZQP@G>4&`*#A
M`#"5Y0,`4N$G```:)-"-XM!`S>'88,WA$-"-X@3PG>0!___KR#"?Y0``4.,#
M,(_@#`"#Y1T```H3___KB#"?Y0-@E.<``);E`___ZU5VP.6=___J"`"4Y0``
M4.,*```*>@<`Z][__^H,`)3EW_[_ZP!@H.'/___J>#"?Y7@`G^4#$)3G``"/
MX$'__^ML`)_E!Q"@X0``C^!]``#K``!0XP@`A.7.__\*[/__ZB;__^L!`*#C
M7?__Z]1V`0`D`0``!`$``!@!```L`0````$``)QW`0"0=P$`J#(``*@R```@
M=P$`E`H```!W`0#<+P``V'8!`)1V`0`P`0``K#```+@N````L*#C`."@XP00
MG>0-(*#A!"`MY00`+>4HH)_E)#"/X@.@BN`@P)_E#,":YP3`+>48,)_E`S":
MYQ0`G^4``)KGH/[_ZY/^_^O\<P$`_````!P!```X`0``%#"?Y10@G^4#,(_@
M`B"3YP``4N,>_R\!E_[_ZMQS`0`(`0``,`"?Y3`PG^4P()_E``"/X`,PC^``
M`%/A`B"/X`0```H<,)_E`S"2YP``4^,````*$_\OX1[_+^$P=0$`+'4!`*AS
M`0`,`0``/`"?Y3PPG^4\()_E``"/X`,PC^``$$/@`B"/X$$1H.&A'X'@P1"P
MX00```H<,)_E`S"2YP``4^,````*$_\OX1[_+^'H=`$`Y'0!`&!S`0`0`0``
M6#"?Y5@@G^4#,(_@`##3Y0(@C^```%/C'O\O$40PG^4(0"WE!."-Y0,PDN<`
M`%/C`@``"C`PG^4#`)_G^O[_Z\?__^LD,)_E`2"@XP!`G>4$T(WB`S"/X``@
MP^4$\)WDF'0!`!1S`0`T`0``+'0!`$QT`0#,___J\#"?Y?!";>'X8,WA`'!0
MXO"!S>$8H(WE'."-Y0,PC^`P```*T""?Y0(PD^<`D)/E``!9XRT```H`,-?E
M/5!3X@%0H!,``%/C`%"@`P``5>,7```:`$"9Y0``5.,-```*`8"@X0E@H.$%
M(*#A!Q"@X00`H.&V_O_K``!0XP(``!H%,-3G/0!3XQ````H$0+;E``!4X_/_
M_QH$`*#AT$#-X=A@S>'0@<WA&*"=Y1S0C>($\)WD!U"@X0$P]>4``%/C/0!3
M$_O__QH'4$7@X/__Z@E@1N`!4(7B1F&@X05`A.``8(CEZ___Z@=`H.'I___J
M"4"@X>?__^J0<@$`(`$``/1!;>&<,)_E`%"@X?A@S>&4<)_E$."-Y0S03>(-
M0*#A!W"/X`-@E^<`,);E!#"-Y000H.$%`*#AL/__ZP``4.,.```*9#"?Y0`0
MG>4#,)?G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#
MY/O__QKK___J!""=Y0`PEN4#`%+A!```&@S0C>+00,WAV&#-X1#0C>($\)WD
M0_[_ZR0!``",<0$`(`$``/1";>$T,I_E`4"@X?A@S>$`4*#A\('-X222G^7X
MH<WA(."-Y0`@T>44T$WB"9"/X`-@F><]`%+C`4"!`@0`H.$`,);E##"-Y0#^
M_^L`<*#A"!"-X@4`H.%[___K`(!0XD,```KY_?_K!P!0X3H``"K0,9_E"("=
MY0.0F><(@:#A`##5Y3T`4^(!`*`3``!3XP``H`,``%#C!0``"@4`H.$!,/#E
M``!3XST`4Q/[__\:!0!`X`)PA^(`H)GE``"'X`S^_^L``%#C"`"*YU@```H`
M()GE`1"%X@@`G>4`,-7E``&2YST`4^,``%,3`##`Y08```H!((#B`3#1Y`(`
MH.$``%/C/0!3$P$PPN3Y__\:/3"@XP`@H.$`,,#E`3#4Y```4^,!,.+E^___
M&@``H.,,()WE`#"6Y0,`4N$^```:%-"-XM!`S>'88,WAT('-X=BAS>$@T(WB
M!/"=Y`$P2.(!(-3D``!2XP$@X^7[__\:[?__ZLPPG^4#D)GG`+"9Y0"@F^4`
M`%KC"!"@`PD```H(,*#A"R"@X0```.H*,*#A!!"RY0&@@^(``%'C^O__&@,P
M@^(#$:#AC#"?Y0,PC^``()/E``!2XQ$``!H!(*#C`0"@X0`@@^7&_?_K`#!0
MX@0PC>42```*"H&@X0L0H.$((*#ASOW_ZP0PG>4`,(GE`2"*X@`0H.,"$8/G
M"*"-Y9K__^H+`*#AYOW_ZP``4.,`,*#A``")Y0$```H*@:#A\O__Z@``X..\
M___JL/W_ZR0!``#,<`$`(`$``+QP`0!@,9_E]$)MX5PAG^7X8,WA`&!0XO"!
MS>'XH<WA`S"/X"#@C>5\T$WB`D"3YP`PE.5T,(WE`@``"@`PUN4``%/C"@``
M&G0@G>4`,)3E`P!2X4,``!I\T(WBT$#-X=A@S>'0@<WAV*'-X2#0C>($\)WD
M)OW_ZP!P4.+Q__\*[("?Y>R0G^7LH)_E"("/X`F0C^`*H(_@!P"@X:;]_^L`
M`%#C*```"A-0@.(($*#A!0"@X;7]_^L``%#C]?__"@D0H.$%`*#AL/W_ZP``
M4./P__\*!@"@X4G]_^L`L*#A!0"@X4;]_^L``(O@`@"`XFW]_^L`L*#A"C"@
MX0!@C>4`(.#C`1"@XP10C>6-_?_K"Q"@X0@@C>(#`*#C5OW_ZP$`<.,+`*#A
M`P``"A@PG>4/.@/B`0E3XP@```HS_?_K"P"@X1G]_^O2___J!P"@X4;]_^L&
M`*#A7_W_Z[G__^JG___K]?__ZE+]_^N,;@$`)`$``,@G``#()P``R"<``(PP
MG^7\0&WA`!"@X83`G^4(X(WE=-!-X@!0H.$-(*#A`P"@XP,PC^`,0)/G`#"4
MY6PPC>5=_?_K``!0XP``H!,$```:$#"=Y0\Z`^(*"E/C`0E3$P<```IL()WE
M`#"4Y0,`4N$)```:=-"-XM!`S>$(T(WB!/"=Y`4`H.$"$*#C\_S_ZQ`/;^&@
M`J#A\?__ZBC]_^L(;0$`)`$``/!";>$<09_E_R\`XQ@QG^7X8,WA`'"@X?"!
MS>$,`9_E`8"@X1B@C>4$0(_@'."-Y0':3>(#H)3G"-!-X@'*C>($8(WB!,",
MX@80H.$``(_@`#":Y0`PC.4J_?_K``!0XRL``-H(4(WB`9!`XL`PG^4)4(7@
M!"!5Y0,PE.<``%+C`$"3Y1H```H`D*#A"2"@X2\0H.,&`*#A,OW_ZP``4.,5
M```*!`"@X;_\_^L),*#A!B"@X0<0H.'6_/_K`3J-X@0P@^(`()/E`#":Y0,`
M4N$3```:`=J-X@C0C>+00,WAV&#-X="!S>$8H)WE'-"-X@3PG>0``%GCX___
M&@0`H.&I_/_K"""@X0<0H.&4_/_KZ?__ZA@PG^4#,)3G`$"3Y?7__^K<_/_K
M:&P!`"0!``#\)0````$```A`+>4\0)_E/#"?Y03@C>4$0(_@`S"4YP``D^64
M_/_K*""?Y2@PG^4H$)_E!."=Y0(@E.<#,(_@`$"=Y0C0C>(!$(_@\/S_ZDAK
M`0```0``%`$``)PD``#@)```8#"?Y0A`+>5<()_E!."-Y0C03>(#,(_@`D"3
MYP``E.5\_/_KWO__ZP``E.5Y_/_K`!"@XS0PG^4T()_E!!"-Y3`0G^4#,(_@
M`B"/X``PC>4!$(_@>/S_ZPC0C>(`0)WE!-"-X@3PG>3H:@$```$``&0G```(
M$0``D"0``-PPG^7T06WAV""?Y?A@S>$0X(WE`MI-XAS03>(#,(_@#$"-X@)0
MD^<"*HWB`6J-XA0@@N(08(;B`#"5Y0`P@N6F_/_KH,"?Y0$@`>,!$*#CF#"?
MY0S`C^`#,(_@`1"-Z`0`H.&L_/_K!`"@X080H.$!*J#CG_S_ZP!`4.(5``"Z
M`0"$XGW\_^L`<%#B!```"@80H.$$(*#A5/S_ZP`PH.,$,,?G`CJ-X@<`H.$4
M,(/B`""3Y0`PE>4#`%+A!P``&@+:C>(<T(WBT$#-X=A@S>$0T(WB!/"=Y`!P
MH./P___J:?S_ZV1J`0`D`0``-"0``"0D``#!___J8#*?Y?1";>$`0*#A6"*?
MY?A@S>$!4*#A\('-X4P"G^7XH<WA`S"/X"#@C>5"W4WB`C"3YPS03>)"+8WB
M&("-X@0@@N(($*#A``"/X!`PC>4`,)/E`#""Y9_]_^L`8*#A+Q"@XP0`H.'O
M^__K``!0XQ,```KX`9_E!!"@X0``C^`"_O_K!`"@X4(]C>($,(/B`""3Y1`P
MG>4`,)/E`P!2X6\``!I"W8WB#-"-XM!`S>'88,WAT('-X=BAS>$@T(WB!/"=
MY`0`H.$$_/_KI!&?Y0"0H.$%`*#A`1"/X#+\_^L`4%#BXO__"HPQG^6,L9_E
MC*&?Y0,PC^`+L(_@%#"-Y0`PU>4*H(_@``!3XS8```H``%;C!```"@40H.$&
M`*#A4?S_ZP``4.,X```*!0"@X>K[_^L!,$#B`R#5YP,PA>`O`%+C!0``&@`0
MH.,`$,/E`2!SY0$`0.(O`%+C^O__"@$PB>(``(/@`0I0X\#__ZH0P9_E"C"@
MX0$JH.,!$*#C"$"-Y8APC>(,P(_@(!"-Z(10C>(%`*#A(?S_ZP@@H.$%$*#A
M`P"@X^K[_^L``%#C`P``&F`P%^4/.@/B`@E3XQ@```K`$)_E``"@XP$0C^#U
M^__K`%"@X0``5>.D__\*`##5Y0``4^/(__\:``!6XQ@```H+$*#A!@"@X1K\
M_^L``%#C"U"@$0$`H!/3__\:>!"?Y0``H.,!$(_@XOO_ZP!0H.'K___J`1"@
MXP4`H.&>^__K``!0X^'__QI0`)_E!1"@X0``C^"0_?_K!0"@X</[_^N+___J
M`0"@XQ10G>6^___JROO_ZV1I`0`D`0``3",``"0C``#8(@``/"(``#@B``"P
M(@``-"(``.0A``"8(0``7"$````PT.4``%/C!0``"@$@@.(O`%/C`@"@`0$P
MTN0``%/C^O__&A[_+^'P06WA`$!0X@A@C>4,X(WE&@``"@!0U.4``%7C%P``
M"G[[_^L!`$#B`""$X`(`5.$+```J`##4YR\`4^,P```:`3!"X@(``.H`$-+E
M+P!1XRL``!H$`%/A`R"@X0$P0^+X__\:`@!4X0L``!HO`%7C+P``"L0`G^4`
M`(_@`0``ZKP`G^4``(_@T$#-X0A@G>4,X)WE$-"-XH'[_^H!($+B`P``Z@`0
MTN4O`%'C`P``&@,@H.$"`%3A`3!"XOC__SH$($+@`C""X@$*4^,``*"#!P``
MBFP`G^4$$*#A`2""X@$ZH.,``(_@`$"@X2W[_^L$`*#AT$#-X0A@G>4,T(WB
M!/"=Y`$P0N("``#J`!#2Y2\`4>/@__\*`P!4X0,@H.$!,$/B^/__.@(`5.'.
M__\*V?__ZA``G^4``(_@T?__ZH0@``#L'P``=&<!`#@?``#@,9_E_$%MX=PA
MG^7X8,WAV,&?Y?"!S>$8X(WE--!-XLP!G^4#,(_@!("-X@*0D^<,P(_@U"',
MX0``C^#<0<SA`'"9Y;SBW.'P(<WAU"+,X?A!S>&<09_E+'"-Y=Q@S.$$0(_@
M^&#-X?`BS>&XXLWAU?S_ZX`!G^4``(_@TOS_ZW@!G^4``(_@S_S_ZW`!G^4`
M`(_@S/S_ZV@!G^4``(_@R?S_ZV`!G^4``(_@QOS_ZU@!G^4``(_@P_S_ZU`!
MG^4``(_@P/S_ZP0`H.&^_/_K0`&?Y0``C^"[_/_K.`&?Y0``C^"X_/_K,`&?
MY0@0H.$``(_@=/S_ZP`04.(!```*!`"@X=W\_^L4`9_E"!"@X0``C^!L_/_K
M`!!0X@(```H``9_E``"/X-3\_^OX`)_E"!"@X0``C^!C_/_K`!!0XA$```KD
M`)_E``"/X,O\_^O<$)_EW`"?Y0$0C^```(_@QOS_ZRP@G>4`,)GE`P!2X1L`
M`!HTT(WBT$#-X=A@S>'0@<WA&-"-X@3PG>2H`)_E"!"@X0``C^!+_/_K`!!0
MX@L``!J4$)_E"B"@XQD`C>(!$(_@&?O_ZP``4./C__\:?`"?Y2,0C>(``(_@
MJ_S_Z][__^IL`)_E``"/X*?\_^O:___JYOK_ZU1E`0`D`0``P!X``'@?``"@
M'P``1!\``$`?``!`'P``/!\``$`?``#0'@``-!\``#@?``"P'@``*!\``!P?
M```<'P``&!\``#P>```D'P``?!X``,@>``#`'@``+!X``!P>``"0$)_E"$`M
MY8P@G^4$X(WE"-!-XH0PG^4!$(_@`D"1YP,PC^```)/E`#"4Y0$`<.,$,(WE
M!P``"@0@G>4`,)3E`P!2X1(``!H(T(WB`$"=Y030C>($\)WD1`"?Y0T0H.$`
M`(_@!?S_ZP``4.,$```*``#0Y3``4.,``%`3`0"@$P``H`,<,)_E`S"/X```
M@^7H___JI_K_ZQ1C`0`D`0``4&0!`$@=``#H8P$`"$`MY03@C>5:^O_K>OK_
MZP``4.,`0)WE!-"-X@``D!4$\)WD\#"?Y?A!;>$`4*#AZ""?Y?A@S>$0@(WE
MX&"?Y13@C>48T$WB`S"/X!`0C>("0)/G!F"/X`8`H.$`,)3E%#"-Y=K[_^L`
M<%#B!1"@X1L```H`,-?E``!3XQ@```IF^O_K``!0XQ@``!H%`*#A4/K_ZP"`
MH.$'`*#A3?K_ZP``B.`"`(#B=/K_ZW3`G^4`@*#A`"#@XVPPG^4!$*#C"'"-
MY0S`C^`#,(_@(!"-Z)'Z_^L($*#A!@"@X2G\_^L"``#J1`"?Y0``C^`E_/_K
M%""=Y0`PE.4#`%+A!0``&AC0C>+00,WAV&#-X1"`G>44T(WB!/"=Y%OZ_^LX
M8@$`)`$``#0=``#D&P``Y!L``*`<``#T0FWA(#>?Y?A@S>'P@<WA&)>?Y?BA
MS>$`L*#A$`>?Y2#@C>6!W$WB#-!-X@F0C^!"7XWB``"/X`/@F>?@8$7B#,"0
MY080H.'8(<#A;,`%Y?@AS>'0(L#A)."-Y0#@GN7\)$7AV"'-X?0E1>'4(,#A
M^"'-X8$\C>($,(/B`."#Y=`AP.$PX)#E_"5%X=@AS>'T)T7AV"+`X9@&G^7X
M)D7A``"/X&#@!>5\^__K`$!0X@(```H`,-3E``!3XXL``!J!___K`'!0XHT`
M``H'`*#A\_G_ZX``H.$!`(#B&OK_ZP`PU^4`H*#A``!3XPP```I$AI_E"D"@
MX0B`C^`$`*#A`#"-Y0`@X.,(,*#A`1"@XS3Z_^L!,/?E`D"$X@``4^/U__\:
M7``5Y0``4.,2```*7$!%X@(``.H$`+3E``!0XPT```H&$*#A5/O_ZP!P4.+X
M__\*`##7Y0``4^/U__\*KOS_ZP``4./R__\*!P"@X>SY_^L`,%#B%P``&@"`
MH.-T<$7B"#&%X'1`$^4``%3C"@``"@`PU.4``%/C!P``"@0`H.$!@(CBG/S_
MZP``4.,$```:"$&7YP``5./T__\:`#"@XP0``.H$`*#AU?G_ZP``4./J__\*
M`#"@X0,`H.$8,(WEKOG_ZP!PH.$*`*#AJ_G_ZP!PA^`!>X?B!'"'X@<`H.'0
M^?_K,.6?Y0!`H.$`(.#C*,6?Y0$0H.,,H(WE&#"=Y0[@C^`,P(_@"%"-Z!`U
MG^4#,(_@ZOG_ZP0`H.$'':#C4?G_ZP$`<.,#```:_/G_ZP`@D.41`%+C`@$`
M&@8@H.$$$*#A`P"@X]?Y_^L`@%#B`P``&M`P%>4/.@/B`0E3XS<```J\))_E
M`1"@XP!PH.,`,)OE`@"9YP!`C>6H))_E``"0Y0(@C^"L^?_K@3R-X@<`H.$$
M,(/B`""3Y20PG>4`,)/E`P!2X14!`!J!W(WB#-"-XM!`S>'88,WAT('-X=BA
MS>$@T(WB!/"=Y/[^_^L$`*#ABOG_ZP!PH.'J___J!T"@X:"`C>($`9CG``!0
MXPP```H&$*#A`4"$XM[Z_^L`,%#B]___"@`PT^4``%/C]/__"GKY_^L``%#C
M\?__"@!PH.%?___J`'2?Y0T`H.-\^?_K`*"@X5,PH.,'<(_@8?__ZLB@%>4T
M^?_K``!:X</__QK0,!7E4S#HYP<-4^.___\:!P"@X6[Y_^L`<*#AO`.?Y080
MH.$``(_@OOK_ZP``4.-6```*`&";Y5SY_^L`$*#A!@"@X0#]_^L`8%#B3P``
M"@8`H.$T^?_K`P!0XP"0H.$,``":>!.?Y00`0.(``(;@`1"/X(_Y_^L``%#C
M!0``&@0`6>.+```*"9"&X`4P6>4O`%/CAP``"H+^_^L`$%#B`P``&@8`H.$N
M^?_K`&!0XC@``!HL$Y_E+`.?Y2RCG^4LDY_E`1"/X"ACG^4``(_@`?O_ZU;Y
M_^L<XY_E"`"-Y0`@X.,4PY_E`1"@XP<`H.$,,Y_E"J"/X`F0C^`&8(_@#N"/
MX`S`C^`#,(_@$!"-Z`S@C>55^?_K#0``ZFOY_^L`,)#E$0!3XP\``!H!@(CB
M/_G_ZU``C>@%(*#A"C"@X0@`C>4!$*#C!P"@X?R`S>%&^?_K!QV@XP<`H.&M
M^/_K`0!PXP!0H.'K__\*!`"@X=CX_^N,`I_E!Q"@X0``C^#5^O_K!P"@X7K^
M_^MI___J`&";Y:W__^H"@*#C`##@XQ$@X.,$D$7B`("-Y07Y_^L)$*#A!B"@
MXP8`H.'(^/_K!#!5Y0``4^,"```:`S!5Y4,`4^-2```*`!"@XP`@H.,`,*#C
M!@"@X0`0C>7U^/_K9@0`ZP"`H.$"``#J"1"@X0@`H.%Y!`#K`BF@XPD0H.$&
M`*#ALOC_ZP`@4.+V___*Y*&?Y08`H.$PL$7BT_C_ZP@0H.%$`$7B"X"@X45@
M1>(*H(_@,9!%XK8$`.L!P/;E"`"@X0HPH.$`(.#C`1"@XP*`B.(`P(WE`/G_
MZP8`6>'U__\:`#"@XY`!G^4`0(WEC,&?Y0BPC>4`(.#C"#!%Y8`QG^4!$*#C
M``"/X`S`C^`#,(_@!,"-Y0P`C>4'`*#A[OC_ZZS__^H$D)OE``!9XW3__PH)
M`*#AE_C_ZP,`4.-P__^:0!&?Y00`0.(``(G@`1"/X//X_^L``%#C"6"@`6C_
M_^K8`)_E`1"@XP!PH.,`,)OE``"9YP!`C>4$((WE""&?Y0``D.4"((_@LOC_
MZP3__^H",%7E00!3XZG__QH!,%7E0P!3XZ;__QH`,-7E2`!3XZ/__QH!,-7E
M10!3XZ#__QH`,.#C.2#@XP"`C>4&`*#AE_C_ZPD0H.$&`*#A*2"@XUKX_^ND
MX)_E`"#@XP$0H..<P)_E!P"@X0B0C>64,)_E#N"/X`S`C^`#,(_@$!"-Z`S@
MC>6P^/_K;O__ZHKX_^LD`0``(&$!`%QB`0"X&@``=!L``%P:``!8&0``0!H`
M`"@!```<&@``!!D``'P9```X&0``%!@``(07``#D&```B!D```P7``"`&0``
M!!<``,`8``!D%@``M!8``.@7``!L%0``&!<``-`6``#X%0``[!8``'`4```<
M%@``;"*?Y?A!;>%H$I_E^&#-X1"`C>5@,I_E%."-Y0C03>("((_@#5"@X0%@
MDN<`$);E!!"-Y0-`DN<``)3E'_C_ZP!PH.$``)3E'/C_ZV0PU^4%$*#A93#`
MY2`"G^4``(_@I/G_ZP``4.,"```*`##0Y3$`4^-A```*Z_S_ZP``E.4.^/_K
M^!&?Y0,PH.,!(*#C`1"/X/'W_^L`<%#B"P``"@``E.4%^/_K##"7Y=0AG^4`
M$)/E`B"/X.[W_^L,,)?E`#"3Y0@PD^4!!1/C6```&@``E.7Y]__KK!&?Y0,P
MH.,!(*#C`1"/X-SW_^L`<%#B"P``"I0!G^4%$*#A``"/X'SY_^L`@%#B``"4
MY3\```KJ]__K##"7Y0@@H.$`$)/EU/?_ZP``E.7D]__K`'"@X0``E.7A]__K
M5!&?Y0$@H.,!$(_@L_?_ZT@AG^4`$*#A!P"@X0(@C^#&]__K``"4Y=;W_^L`
M,*#A+`&?Y0`@H.,%$*#A)%&?Y64@P^4``(_@7/G_ZP50C^```%#C`$"@X0@`
MA>40```*!QV@XP0`H.&0]__K`3"`XA$`4.,!`%,3)@``B@0@G>4`,);E`P!2
MX2$``!H(T(WBT$#-X=A@S>$0@)WE%-"-X@3PG>0$`)7EG/W_ZP``4.,`0*#A
M"`"%Y>C__QJH`)_E``"/X/WW_^L!,-#E``!3XYO__PJ9___JJO?_ZXPPG^4,
M()?E`S"/X`0PD^4``)+E`!"3Y;CZ_^N[___J``"4Y:#W_^L,,)?E`!"3Y=#W
M_^N@___JU_?_ZU00G^4`,*#A!""@X4P`G^4!$(_@!!"1Y0``C^``$)'EX/?_
MZX19`0`D`0````$``*@3```L%0``#!4``.04``#`$@``C!0``)`4```T$@``
MH%D!`/03```(60$`Q%@!`*@3``#P06WA`%"@X0A@C>4,X(WE!/S_ZP`PT.4`
M0*#A``!3XP4```H!((#B+P!3XP)`H`$!,-+D``!3X_K__QK@_/_K``!5XP``
M4!,#```:T$#-X0A@G>4,T(WB!/"=Y``PU>4``%/C^/__"BP0G^4$`*#A!""@
MXP$0C^#&]__K``!0X_'__QH%`*#AT$#-X0A@G>4,X)WE$-"-XNKY_^JP$0``
M_#N?Y?1";>$<((#B]$N?Y?A@S>%<P(#B\('-X?BAS>$#,(_@(."-Y57?3>($
M,)/G"."-X@X0H.$$,(WE`#"3Y4PQC>4$,)+D,S^_Y@(`7.$$,*'E^O__&D)/
MC>(.(*#A!!"^Y23`DN4X,)+E#""2Y00`7N$,,"/@`C`CX`$P(^#C/Z#A0#".
MY?/__QH`@)#EF1D'XZ$K#N/48,#A@AI%X]DN1N,,4)#EW#P+XQ#@G>4;/TCC
M#,"=Y69!H.$0H)#E!9`GX`2P)^`!X([@"+`+X`'`C.`%X([@![`KX`K`C.`.
ML(O@%."=Y6BAH.$&D`G@Z,V,X`60*>`)P(S@"I`DX`R0">`!X([@!)`IX`?@
MCN`.D(G@&."=Y>R]B^!LP:#AZYV)X`'@CN`$0([@#.`JX`O@#N!KL:#A"N`N
MX`1`CN`<X)WEZ4V$X`'@CN`*H([@"^`LX`G@#N!ID:#A#.`NX`K@CN`@H)WE
MY.V.X`&@BN`,H(K@"<`KX`3`#.!D0:#A"\`LX`K`C.`DH)WE[LV,X`&@BN`+
MH(K@!+`IX`ZP"^!NX:#A";`KX`JPB^`HH)WE[+V+X`&@BN`)H(K@#I`DX`R0
M">!LP:#A!)`IX`J0B>`LH)WEZYV)X`&@BN`$H(K@#$`NX`M`!.!KL:#A#D`D
MX`I`A.`PH)WEZ4V$X`&@BN`.H(K@"^`LX`G@#N!ID:#A#.`NX`K@CN`TH)WE
MY.V.X`&@BN`,H(K@"<`KX`3`#.!D0:#A"\`LX`K`C.`XH)WE[LV,X`&@BN`+
MH(K@!+`IX`ZP"^!NX:#A";`KX`JPB^`\H)WE[+V+X`&@BN`)H(K@#I`DX`R0
M">!LP:#A!)`IX`J0B>!`H)WEZYV)X`&@BN`$H(K@#$`NX`M`!.!KL:#A#D`D
MX`I`A.!$H)WEZ4V$X`&@BN`.H(K@"^`LX`G@#N!ID:#A#.`NX`K@CN!(H)WE
MY.V.X`&@BN`,H(K@"<`KX`3`#.!D0:#A"\`LX`K`C.!,H)WE[LV,X`&@BN`+
ML(K@!*`IX`Z@"N!NX:#A":`JX`NPBN!0H)WE[+V+X`&@BN`)H(K@#I`DX`R0
M">!LP:#A!)`IX`J0B>!4H)WEZYV)X`&@BN`$H(K@#$`NX`M`!.!KL:#A#D`D
MX`J@A.!80)WE`4"$X.D=BN!@H)WE#D"$X`O@+.`)X`[@:9&@X0S@+N`$X([@
M7$"=Y>'MCN`"0(3@#,"$X`E`*^`!0"3@81&@X03`C.`"0(K@[JV,X`'`*>`.
MP"S@"T"$X`Q`A.!DP)WE;K&@X>I-A.`+X"'@"N`NX`+`C.`)P(S@:I&@X0[@
MC.!HP)WE":`KX.3MCN`$H"K@9$&@X0+`C.`!$(S@;,"=Y0H0@>`$H"G@#J`J
MX.X=@>!NX:#A`L",X`O`C.`.L"3@"L",X'"@G>4!L"O@X<V,X&$1H.$"H(K@
M":"*X'20G>4+H(K@[*V*X`*0B>`$0(G@`9`NX`R0*>!LP:#A"9"$X'A`G>7J
MG8G@`K"$X`Y`B^`,X"'@"N`NX&JQH.$.0(3@?."=Y8"@G>7I383@`N".X`$0
MCN`+X"S@">`NX&F1H.$.X('@`A"*X`F@*^`,$('@A,"=Y>3MCN`$H"K@9$&@
MX0H0@>#N'8'@!*`IX`+`C.`.H"K@"\",X&[AH.$*P(S@B*"=Y0ZP).#AS8S@
M`;`KX&$1H.$"H(K@":"*X(R0G>4+L(K@[+V+X`*0B>`$0(G@`9`NX`R0*>!L
MP:#A"9"$X)!`G>7KG8G@`J"$X`Y`BN`,X"'@"^`NX&NAH.&8L)WE#D"$X)3@
MG>7I383@`N".X`$0CN`*X"S@">`NX&F1H.$.$('@Y.V!X`(0B^`,$('@G,"=
MY0FP*N`$L"O@9$&@X0NP@>`"P(S@!!`IX`X0(>`*P(S@`<",X*`0G>7NO8O@
M;N&@X>O-C.`.H"3@`A"!X`N@*N`)D('@I!"=Y6NQH.$*D(G@J*"=Y>R=B>`"
M$('@!!"!X`M`+N`,0"3@;,&@X0(@BN`.((+@#.`KX`G@+N`$$('@#B""X*S@
MG>5I0:#AZ1V!X`20C.$!D`G@X2V"X`/@CN`+L([@!.`,X`[@B>&PD)WE81&@
MX0O@CN"TL)WE`:"$X>+MCN`"H`K@`Y")X&(AH.$,D(G@`<`$X`.PB^`,P(KA
MN*"=Y02PB^`)0(S@;I&@X0+`@>'N383@#L`,X`+@`>`.X(SA"<""X0O@CN`$
MP`S@`["*X`F@`N`!L(O@"L",X;P0G>4+P(S@P+"=Y>3MCN!D0:#A[LV,X`2@
MB>$#$('@#J`*X`(@@>!NX:#A!!`)X`.PB^`!$(KA";"+X,20G>4"$('@#B"$
MX>P=@>`,(`+@;,&@X0Z@!.`#D(G@"B""X0R@CN$$0(G@`:`*X`R0#N`+((+@
MS+"=Y0F@BN'A+8+@!*"*X,A`G>5A$:#AXJV*X`&0C.$#L(O@`T"$X`*0">`.
M0(3@8B&@X0'@#.`.X(GA#+"+X`1`CN`"P('A:I&@X>I-A.`"X`'@#*`*X`[@
MBN'0H)WE"<""X0O@CN`$P`S@Y.V.X&1!H.$#L(K@":`"X`&PB^`*P(SAU!"=
MY0O`C.#8L)WE!*")X>[-C.`.H`K@;N&@X0,0@>`"(('@`["+X`00">`)L(O@
MW)"=Y0$0BN$.H`3@`A"!X`X@A.'L'8'@#"`"X&S!H.$#D(G@"B""X0R@CN$!
MH`K@!$")X`R0#N`+((+@Y+"=Y0F0BN'A+8+@!$")X."0G>5A$:#AXDV$X`&@
MC.$#L(O@`Y")X`*@"N`.D(G@8B&@X0'@#.`.X(KA`J"!X0G@CN`$H`K@9)&@
MX>3MCN`"0`'@#,"+X`1`BN$)H(+A#,"$X.A`G>4.H`K@[LV,X`FP`N!NX:#A
M"["*X0-`A.`.H(GA`1"$X.Q`G>4,H`K@`1"+X/"PG>7L'8'@;,&@X0-`A.`"
M((3@#D`)X`1`BN$#H(O@`D"$X`P@CN'A383@`;`"X&$1H.$,(`[@"9"*X`(@
MB^'TH)WE`;",X0D@@N`$L`O@`9`,X`FPB^'XD)WEY"V"X`.@BN!D0:#A#N"*
MX`,PB>`.D(O@!."!X02@`>`"X`[@#,"#X`K@CN'6,0SC#,".X/S@G>5B.DSC
MXIV)X&(AH.$`L9WEZ<V,X`/@CN`!$([@`N`DX`G@+N!ID:#A#A"!X.SM@>`$
M$9WE`Z"+X`1`BN`,L9WE":`BX`R@*N!LP:#A`Q"!X`(@@>`,$"G@#A`AX`I`
MA.`!((+@"!&=Y>Y-A.!NX:#AY"V"X`.@@>!D$:#A":"*X`Z0+.`)0"3@!*"*
MX`-`B^`4L9WE#,"$X`%`+N`"0"3@XJV*X`1`C.`0P9WE8B&@X6J1H.'J383@
M`\",X`[@C.`"P"'@"L`LX`S`CN`#X(O@'+&=Y0$0CN`)X"+@!.`NX.3-C.`.
M$('@&.&=Y61!H.'L'8'@!*`IX`R@*N`#X([@;,&@X0+@CN`*H([@`R"+X`S@
M).`DL9WE"2""X`'@+N`.X(+@("&=Y>&MBN!A$:#AZNV.X`.0@N!J(:#A!)")
MX`%`+.`*0"3@!$")X`.0B^`LL9WE#,")X`*0(>`.D"G@[DV$X`G`C.`HD9WE
M;N&@X>3-C.`#H(G@9)&@X0&@BN`.$"+@!!`AX`-`B^`TL9WE`B"$X`E`+N`,
M0"3@`1"*X`0@@N`P09WE[!V!X&S!H.'A+8+@#*`IX`&@*N`#0(3@81&@X0Y`
MA.`*0(3@`^"+X`&@+.`\L9WE">".X`*@*N#B383@8I&@X0H@CN`XX9WEY"V"
MX`.@CN!DX:#A#*"*X`G`(>`$P"S@`T"+X$2QG>4!$(3@#D`IX`)`).`,P(K@
M!!"!X$!!G>7BS8S@8B&@X>P=@>`#H(3@;$&@X0F@BN`"D"[@"<`LX`.0B^!(
ML9WE#,"*X`[@B>!,H9WE!)`BX.'-C.`!D"G@81&@X0,PB^`)X([@"#"#X`&0
M).#L[8[@`C"#X!`@D.4,D"G@"9"#X&S!A^#N/8G@#N"&X`$0A>`$0(+@"$"`
MZ`0PG>4(P(#E#!"`Y1!`@.4`,)/E`P!:X08``!I5WXWBT$#-X=A@S>'0@<WA
MV*'-X2#0C>($\)WDE?3_ZS!6`0`D`0``"$`MY6``H..)2PKC!."-Y<U/3N.*
M]/_K`2,"X_[L#>-%)T;CNNA)XW;$!>/P$0[C%$"`Z#+`0>,`(*#CTA-,XPS`
M@.40$(#E%""`Y1@@@.5<((#E`$"=Y030C>($\)WD\$)MX0!0H.$!0*#A^&#-
MX1QP@.+P@<WA`I"@X8(AH.$8H(WE'."-Y10PD.4",)/@&""0Y0$0H"-<`)#E
M`!"@,P``4>,4,(7E`2""$JDN@N```%#C&""%Y14```I`@&#B!!"@X0@`6>$`
M`(?@"8"@L0@@H.$V]/_K7#"5Y0,PB.!``%/C7#"%Y04```K00,WAV&#-X="!
MS>$8H)WE'-"-X@3PG>0%`*#A")!)X`A`A."W_/_K/P!9XQ@``-I`D$GB*6.@
MX0&`AN((@X3@!!"@X4`@A.(',*#A`$"1Y1`0@>(0,(/B#.`1Y0C`$>4$`!'E
M`@!1X1!``^4,X`/E",`#Y00``^7S__\:`4"@X04`H.&?_/_K"`!4X>O__QH&
MDTG@!!"@X0<`H.$)(*#A"/3_ZUR0A>74___J^$%MX0%`H.%_$.#C^&#-X0!0
MH.$0@(WE'("$XA3@C>748<3AUC'EYP$@@^(X`%+C`Q#(YP(`B.!&``#*."!B
MX@`0H./*\__K)SR@X2<8H.$F+*#A!`"@X50PQ.4F.*#A51#$Y5=PQ.4G=*#A
M6V#$Y29DH.%6<,3E6"#$Y5DPQ.5:8,3E=/S_ZP,PU.4$`*#A`##%Y;(PU.$!
M,,7E`#"4Y2,TH.$",,7E`#"4Y0,PQ>4',-3E!##%Y;8PU.$%,,7E!#"4Y2,T
MH.$&,,7E!#"4Y0<PQ>4+,-3E"##%Y;HPU.$),,7E"#"4Y2,TH.$*,,7E"#"4
MY0LPQ>4/,-3E###%Y;XPU.$-,,7E##"4Y2,TH.$.,,7E##"4Y0\PQ>43,-3E
M$##%Y;(QU.$1,,7E$#"4Y2,TH.$2,,7E$#"4Y1,PQ>700,WAV&#-X1"`G>44
MX)WE&-"-XI7S_^I`(&+B`!"@XX/S_^L$`*#A._S_ZP@`H.$X(*#C`!"@XWWS
M_^NQ___J\$)MX710G^7X8,WA<&"?Y0!PH.'P@<WA`8"@X0*0H.$8H(WE!5"/
MX!S@C>4&8(_@!6!&X$7S_^M&8;#A"0``"@101>(`0*#C`4"$X@0PM>4)(*#A
M"!"@X0<`H.$S_R_A!`!6X??__QK00,WAV&#-X="!S>$8H)WE'-"-X@3PG>3@
M10$`W$4!`![_+^$(,)_E`S"/X``PD^6U\__JW$<!``A`+>D(@+WH`0`"`'!E
M<FQX<VDN8P```%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@````
M`"X````N+@``)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ
M8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C
M+R5I+R5S`&5X90!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S
M)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$52
M3$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````
M4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!3%]$14)51P````!0
M05)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-
M4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3CT``#$```!,1%],24)2
M05)97U!!5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES
M('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R
M871I;VXI"@``4$%42`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S
M)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````!@```!P
M97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U,@```%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H`````+64``"TM``!54T52`````%5315).04U%`````%1%35!$
M25(`5$U0`"]T;7``````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T
M96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G
M+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF
M:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC
M:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO
M9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N
M960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I
M;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)
M0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\.G)A
M=R<L("1P<F]G;F%M92!O<B!L87-T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US
M("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M
M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?
M<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ
M92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD
M;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA
M9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?<&]S+"`P.PIR96%D
M(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD[
M"FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I
M('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C
M:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L(#0["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD
M9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?
M1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D
M('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG
M($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE
M(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B
M87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ
M*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O
M7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?
M87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U
M;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E
M>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD[
M"GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L
M"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]
M"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?
M.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O
M(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD
M24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T
M(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^
M<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M
M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE
M(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S
M<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C
M;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@
M=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*
M:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@
M0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE
M;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,[
M"G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU
M<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D
M9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E
M("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I
M9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q
M(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q
M)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D
M;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE
M("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE
M(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M
M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D[
M"G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II
M9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF
M="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M
M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R
M(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO
M<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]
M"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M
M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O
M+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=
M*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M
M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R
M(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T
M.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O
M=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z
M.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z
M.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I
M;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@
M,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)&1A=&%?<&]S*2!["G)E860@
M7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@96QS92!["FQO8V%L("0O(#T@
M=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G
M:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@
M/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD
M;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I
M.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M
M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"![
M"B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L
M:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN
M8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E
M>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS
M;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F
M:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E
M86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O
M*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0[
M"GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@
M*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D
M9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]
M"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[
M)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<
M+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,
M12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE
M*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]
M("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E
M;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)&9H/CL*8VQO<V4@)&9H.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E
M9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]
M"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K
M(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E
M0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O
M;G1E;G0I*2P*)&-O;G1E;G0I.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE
M(ETI.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP
M.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF
M("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY
M72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D
M9F@L("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4@
M)&9H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?
M;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A
M8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC
M:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE
M9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE
M.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H
M:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E
M;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D
M.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D
M<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q
M,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!]
M(ETI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B
M92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II
M<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*
M;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL
M97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z
M.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA
M;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM
M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]4
M14U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US
M(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;
M4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES
M=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C
M=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92)=*3L*)&UE;6)E
M<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U
M+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S
M<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N
M;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=
M(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;
M("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#
M<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"
M87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@
M1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H
M+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q
M=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E
M<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W
M87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I
M<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V
M86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE
M=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@
M07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ
M2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@
M<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X
M('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?
M=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@
M)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@
M5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S
M(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@
M)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U
M:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ
M3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64[
M"GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I
M9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.
M5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<[
M"FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP
M86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII
M9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R
M;V=N86UE*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PIS965K
M("1F:"P@+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@-CL*:68@
M*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G)E860@
M)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92!["FUY("1D:6=E
M<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I
M9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O
M9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E
M<W0["GT@?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM0
M05)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E
M;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B
M(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?
M.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M
M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"([
M"F]P96X@;7D@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A
M;B=T('=R:71E("(D=&5M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N
M=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I
M;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N
M;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E
M>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]
M"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W
M9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]
M7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``(&R`8&PL*X'
M`````(:R`8&PL*L/`````**R`8&PL*\'`````,*R`8&PL*\_`````'R0_W^P
MJPB`))/_?P$```"LE/]_L+"N@*25_W^PJP*`4);_?["O!("8F/]_L*\>@`R:
M_W^PJ1R`H)K_?Y3__W_0F_]_L+"H@"2<_W^PJ`&`F)S_?XC__W^$G?]_L+"P
M@("=_W^$__]_$*#_?["PL(`PH/]_L+"J@'BA_W^PK0R`O*/_?["H`8!@I/]_
ML+"H@'RD_W^PK`6`A*7_?UC__W\DK?]_L*P!@-"O_W^PL*J`:+#_?Z\_%(!L
MO/]_L+"H@,2\_W^PL*Z`]+W_?["PK(!LO_]_L+"N@.R__W^PL+"`_+__?P$`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$@=``#4'````0```$X#```!
M````60,```$```!I`P```0```',#```!````AP,``!T````1!0``#````!P6
M```-````;$D``!D```#8C@$`&P````0````:````W(X!`!P````$````!```
M`+0!``#U_O]O]`0```4```"T#```!@```.0%```*````1@4```L````0````
M%0`````````#`````)`!``(```#@`0``%````!$````7````/!0``!$```!4
M$P``$@```.@````3````"````/O__V\````(_O__;]02``#___]O!````/#_
M_V_Z$0``^O__;Q``````````````````````````````````````````````
M````````````X(X!````````````*!8``"@6```H%@``*!8``"@6```H%@``
M*!8``"@6```H%@``*!8``"@6```H%@``*!8``"@6```H%@``*!8``"@6```H
M%@``*!8``"@6```H%@``*!8``"@6```H%@``*!8``"@6```H%@``*!8``"@6
M```H%@``*!8``"@6```H%@``*!8``"@6```H%@``*!8``"@6```H%@``*!8`
M`"@6```H%@``*!8``"@6```H%@``*!8``"@6```H%@``*!8``"@6```H%@``
M*!8``"@6```H%@``*!8``"@6```H%@``*!8``"@6```H%@``5$D`````````
M``````````````````````````````#,2```````````````````````````
M````````#!D```````!`D0$`_____]A,``"H20```````,A*``#,2@``S$P`
M`!!*``#43````````+A,``#`3````````.!,``!'0T,Z("A355-%($QI;G5X
M*2`W+C4N,`!!,@```&%E86)I``$H````!3<M00`&"@=!"`$)`@H$$@03`10!
M%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U
M:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T
M<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP
M;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X=&%B`"Y!4DTN
M97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA
M;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`
M```````````````````````````````````````````````````````+````
M`0````(```!4`0``5`$``!D```````````````$`````````$P````<````"
M````<`$``'`!```D```````````````$`````````"8````'`````@```)0!
M``"4`0``(```````````````!``````````X````!0````(```"T`0``M`$`
M`$`#```&``````````0````$````-````/;__V\"````]`0``/0$``#P````
M!@`````````$````!````#X````+`````@```.0%``#D!0``T`8```<````#
M````!````!````!&`````P````(```"T#```M`P``$8%``````````````$`
M````````3@```/___V\"````^A$``/H1``#:````!@`````````"`````@``
M`%L```#^__]O`@```-02``#4$@``@`````<````$````!`````````!J````
M"0````(```!4$P``5!,``.@````&``````````0````(````<P````D```!"
M````/!0``#P4``#@`0``!@```!<````$````"````'P````!````!@```!P6
M```<%@``#```````````````!`````````!W`````0````8````H%@``*!8`
M`.0"``````````````0````$````@@````$````&````#!D```P9``!@,```
M```````````$`````````(@````!````!@```&Q)``!L20``"```````````
M````!`````````".`````0````(```!T20``=$D``.L^``````````````0`
M````````E@````$````"````8(@``&"(```P```````````````$````````
M`*$````!``!P@@```)"(``"0B```Z`````X`````````!`````````"L````
M`0````(```!XB0``>(D```0```````````````0`````````M@````X````#
M````V(X!`-B.```$```````````````$````!````,(````/`````P```-R.
M`0#<C@``!```````````````!`````0```#.````!@````,```#@C@$`X(X`
M`"`!```'``````````0````(````UP````$````#`````)`!``"0```\`0``
M```````````$````!````-P````!`````P```#R1`0`\D0``0```````````
M````!`````````#B````"`````,```!\D0$`?)$``!00``````````````0`
M````````YP````$````P`````````'R1```8```````````````!`````0``
M`/`````#``!P``````````"4D0``,P```````````````0`````````!````
D`P``````````````QY$````!``````````````$`````````
